@@ -1,17 +1,17 @@
 import dask
 import dask.distributed
-from dagster_graphql.client.mutations import execute_execute_plan_mutation
-
-# Dask resource requirements are specified under this key
-from dagster import Executor, Field, Permissive, Selector, check, seven
+from dagster import Executor, Field, Permissive, Selector, StringSource, check, seven
 from dagster.core.definitions.executor import check_cross_process_constraints, executor
+from dagster.core.errors import raise_execution_interrupts
 from dagster.core.events import DagsterEvent
+from dagster.core.execution.api import create_execution_plan, execute_plan
 from dagster.core.execution.context.system import SystemPipelineExecutionContext
 from dagster.core.execution.plan.plan import ExecutionPlan
 from dagster.core.execution.retries import Retries
-from dagster.utils import frozentags
-from dagster.utils.hosted_user_process import create_in_process_ephemeral_workspace
+from dagster.core.instance import DagsterInstance
+from dagster.utils import frozentags, iterate_with_context
 
+# Dask resource requirements are specified under this key
 DASK_RESOURCE_REQUIREMENTS_KEY = "dagster-dask/resource_requirements"
 
 
@@ -21,6 +21,9 @@ DASK_RESOURCE_REQUIREMENTS_KEY = "dagster-dask/resource_requirements"
         "cluster": Field(
             Selector(
                 {
+                    "existing": Field(
+                        {"address": StringSource}, description="Connect to an existing scheduler.",
+                    ),
                     "local": Field(
                         Permissive(), is_required=False, description="Local cluster configuration."
                     ),
@@ -62,7 +65,7 @@ def dask_executor(init_context):
     """Dask-based executor.
 
     The 'cluster' can be one of the following:
-    ('local', 'yarn', 'ssh', 'pbs', 'moab', 'sge', 'lsf', 'slurm', 'oar', 'kube').
+    ('existing', 'local', 'yarn', 'ssh', 'pbs', 'moab', 'sge', 'lsf', 'slurm', 'oar', 'kube').
 
     If the Dask executor is used without providing executor-specific config, a local Dask cluster
     will be created (as when calling :py:class:`dask.distributed.Client() <dask:distributed.Client>`
@@ -102,12 +105,23 @@ def dask_executor(init_context):
 
 
 def query_on_dask_worker(
-    workspace, variables, dependencies, instance_ref=None
+    dependencies, recon_pipeline, pipeline_run, run_config, step_keys, mode, instance_ref,
 ):  # pylint: disable=unused-argument
     """Note that we need to pass "dependencies" to ensure Dask sequences futures during task
     scheduling, even though we do not use this argument within the function.
     """
-    return execute_execute_plan_mutation(workspace, variables, instance_ref=instance_ref)
+
+    with DagsterInstance.from_ref(instance_ref) as instance:
+        execution_plan = create_execution_plan(
+            recon_pipeline.subset_for_execution_from_existing_pipeline(
+                pipeline_run.solids_to_execute
+            ),
+            run_config=run_config,
+            step_keys_to_execute=step_keys,
+            mode=mode,
+        )
+
+        return execute_plan(execution_plan, instance, pipeline_run, run_config=run_config)
 
 
 def get_dask_resource_requirements(tags):
@@ -139,29 +153,22 @@ class DaskExecutor(Executor):
             "Expected executor to be DaskExecutor got {}".format(pipeline_context.executor),
         )
 
-        # Checks to ensure storage is compatible with Dask configuration
-        storage = pipeline_context.run_config.get("storage")
-        check.invariant(storage.keys(), "Must specify storage to use Dask execution")
-
         check.invariant(
             pipeline_context.instance.is_persistent,
             "Dask execution requires a persistent DagsterInstance",
         )
 
-        # https://github.com/dagster-io/dagster/issues/2440
-        check.invariant(
-            pipeline_context.system_storage_def.is_persistent,
-            "Cannot use in-memory storage with Dask, use filesystem, S3, or GCS",
-        )
-
-        step_levels = execution_plan.execution_step_levels()
+        step_levels = execution_plan.get_steps_to_execute_by_level()
 
         pipeline_name = pipeline_context.pipeline_def.name
 
         instance = pipeline_context.instance
 
         cluster_type = self.cluster_type
-        if cluster_type == "local":
+        if cluster_type == "existing":
+            # address passed directly to Client() below to connect to existing Scheduler
+            cluster = self.cluster_configuration["address"]
+        elif cluster_type == "local":
             from dask.distributed import LocalCluster
 
             cluster = LocalCluster(**self.build_dict(pipeline_name))
@@ -203,7 +210,7 @@ class DaskExecutor(Executor):
             cluster = KubeCluster(**self.build_dict(pipeline_name))
         else:
             raise ValueError(
-                f"Must be providing one of the following ('local', 'yarn', 'ssh', 'pbs', 'moab', 'sge', 'lsf', 'slurm', 'oar', 'kube') not {cluster_type}"
+                f"Must be providing one of the following ('existing', 'local', 'yarn', 'ssh', 'pbs', 'moab', 'sge', 'lsf', 'slurm', 'oar', 'kube') not {cluster_type}"
             )
 
         with dask.distributed.Client(cluster) as client:
@@ -221,31 +228,19 @@ class DaskExecutor(Executor):
 
                     run_config = dict(pipeline_context.run_config, execution={"in_process": {}})
                     recon_repo = pipeline_context.pipeline.get_reconstructable_repository()
-                    variables = {
-                        "executionParams": {
-                            "selector": {
-                                "pipelineName": pipeline_name,
-                                "repositoryName": recon_repo.get_definition().name,
-                                "repositoryLocationName": "<<in_process>>",
-                            },
-                            "runConfigData": run_config,
-                            "mode": pipeline_context.mode_def.name,
-                            "executionMetadata": {"runId": pipeline_context.pipeline_run.run_id},
-                            "stepKeys": [step.key],
-                        }
-                    }
 
                     dask_task_name = "%s.%s" % (pipeline_name, step.key)
 
-                    workspace = create_in_process_ephemeral_workspace(
-                        pointer=pipeline_context.pipeline.get_reconstructable_repository().pointer
-                    )
+                    recon_pipeline = recon_repo.get_reconstructable_pipeline(pipeline_name)
 
                     future = client.submit(
                         query_on_dask_worker,
-                        workspace,
-                        variables,
                         dependencies,
+                        recon_pipeline,
+                        pipeline_context.pipeline_run,
+                        run_config,
+                        [step.key],
+                        pipeline_context.mode_def.name,
                         instance.get_ref(),
                         key=dask_task_name,
                         resources=get_dask_resource_requirements(step.tags),
@@ -256,10 +251,12 @@ class DaskExecutor(Executor):
 
             # This tells Dask to awaits the step executions and retrieve their results to the
             # master
-            for future in dask.distributed.as_completed(execution_futures):
-                for step_event in future.result():
-                    check.inst(step_event, DagsterEvent)
+            futures = dask.distributed.as_completed(execution_futures, with_results=True)
 
+            # Allow interrupts while waiting for the results from Dask
+            for future, result in iterate_with_context(raise_execution_interrupts, futures):
+                for step_event in result:
+                    check.inst(step_event, DagsterEvent)
                     yield step_event
 
     def build_dict(self, pipeline_name):
